<?php

switch ($messaggio) {

case "Modifica o cancella la prenotazione":	$messaggio = "&Auml;ndra eller ta bort bokning"; break;
case "Prenotazione a nome di":  		$messaggio = "Bokning f&ouml;r"; break;
case "nato il":  				$messaggio = "f&ouml;dd"; break;
case "nata il":  				$messaggio = "f&ouml;dd"; break;
case "e":  					$messaggio = "och"; break;
case "CAP":  					$messaggio = "postnummer"; break;
case "Telefono":  				$messaggio = "Telefon"; break;
case "2º telefono":  				$messaggio = "Andra telefon"; break;
case "3º telefono":  				$messaggio = "Tredje telefon"; break;
case "Modifica i dati del cliente":  		$messaggio = "&Auml;ndra kunddata"; break;
case "La prenotazione è dell'anno precedente, si potrà modificare solo la data finale":	$messaggio = "Bokningen &auml;r fr&aring;n ett tidigare &aring;r. Du kommer bara kunna &auml;ndra slutdatumet"; break;
case "settimane":  				$messaggio = "veckor"; break;
case "giorni":  				$messaggio = "dagar"; break;
case "giorno":  				$messaggio = "day"; break;
case "dal":  					$messaggio = "fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "cambia in":  				$messaggio = "&auml;ndra till"; break;
case "in":  					$messaggio = "i"; break;
case "Nº di piano":  				$messaggio = "V&aring;ning nummer"; break;
case "e/o di casa":  				$messaggio = "och/eller hus nummer"; break;
case "e/o di persone":  			$messaggio = "och/eller antal personer"; break;
case "Nº di persone":  				$messaggio = "Antal personer"; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "Cancella il commento":  			$messaggio = "Ta bort kommentar"; break;
case "Tipo di tariffa":  			$messaggio = "Pristyp"; break;
case "tariffa":  				$messaggio = "pris"; break;
case "Sconto":  				$messaggio = "Rabatt"; break;
case "Caparra":  				$messaggio = "Deposition"; break;
case "resto":  					$messaggio = "&aring;terst&aring;r"; break;
case "Ricalcola la caparra in base alla nuova tariffa":	$messaggio = "Ber&auml;kna &aring;terigen depositionen utifr&aring;n det nya priset"; break;
case "Costo aggiuntivo unico":  		$messaggio = "Enkel extrakostnad"; break;
case "moltiplicato per":  			$messaggio = "multiplicerat med"; break;
case "Costo aggiuntivo settimanale":  		$messaggio = "Veckolig extrakostnad"; break;
case "Costo aggiuntivo giornaliero":  		$messaggio = "Daglig extrakostnad"; break;
case "per":  					$messaggio = "f&ouml;r"; break;
case "settimane moltiplicato per":  		$messaggio = "veckor mulitplicerat med"; break;
case "giorni moltiplicato per":  		$messaggio = "dagar multiplicerat med"; break;
case "della tariffa moltiplicato per":  	$messaggio = "av priset multiplicerat med"; break;
case "Prenotazione confermata":  		$messaggio = "Bokning bekr&auml;ftad"; break;
case "Totale da pagare":  			$messaggio = "Totalt att betala"; break;
case "Pagato":  				$messaggio = "Betald"; break;
case "aggiungi":  				$messaggio = "l&auml;gg till"; break;
case "pagato tutto":  				$messaggio = "alla betalda"; break;
case "caparra ":  				$messaggio = "deposition betald"; break;
case "Ancora da pagare":  			$messaggio = "Kvar att betala"; break;
case "Nuovo costo aggiuntivo unico":  		$messaggio = "Ny enkel extrakostnad"; break;
case "di":  					$messaggio = "f&ouml;r"; break;
case "da moltiplicare per":  			$messaggio = "att multiplicera med"; break;
case "letto":  					$messaggio = "s&auml;ng"; break;
case "straordinario":  				$messaggio = "extraordin&auml;r"; break;
case "Nuovo costo aggiuntivo settimanale":	$messaggio = "Ny veckolig extrakostnad"; break;
case "Nuovo costo aggiuntivo giornaliero":  	$messaggio = "Ny daglig extrakostnad"; break;
case "nº di settimane da applicare":  		$messaggio = "antal veckor att till&auml;mpa f&ouml;r"; break;
case "nº di giorni da applicare":  		$messaggio = "antal dagar att till&auml;mpa f&ouml;r"; break;
case "non specificato":  			$messaggio = "inte specificerat"; break;
case "Modifica la prenotazione":  		$messaggio = "&Auml;ndra bokning"; break;
case "Cancella la prenotazione":  		$messaggio = "Ta bort bokning"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "SI":  					$messaggio = "JA"; break;
case "cancella anche ciò che era stato pagato":	$messaggio = "ta ocks&aring; bort det som betalats"; break;
case "NO":  					$messaggio = "NEJ"; break;
case "La prenotazione":  			$messaggio = "Bokningen"; break;
case "era già stata cancellata":  		$messaggio = "har redan tagits bort"; break;
case "Prenotazione":  				$messaggio = "Bokning"; break;
case "cancellata":  				$messaggio = "borttagen"; break;
case "<b>non è stata cancellata</b> perchè è stata modificata nel frattempo":	$messaggio = "<b>har inte tagits bort</b> eftersom den har &auml;ndrats under tiden"; break;
case "Si è sicuri di voler <b>cancellare</b> la prenotazione":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <b>ta bort</b> bokningen"; break;
case "Si è sicuri di voler <b>cancellare</b> le prenotazioni":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <b>ta bort</b> bokningarna"; break;
case "La data iniziale verrà cambiata dal":  	$messaggio = "Startdatumet kommer &auml;ndras fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "La data finale verrà cambiata dal":  	$messaggio = "Slutdatumet kommer &auml;ndras fr&aring;n"; break;
case "Le <div style=\"display: inline; color: red;\">date</div> sono <b>sbagliate</b>":	$messaggio = "<div style=\"display: inline; color: red;\">Datumen</div> &auml;r <b>felaktiga</b>"; break;
case "della casa":  				$messaggio = "i huset"; break;
case "con massimo numero di occupanti":  	$messaggio = "med maximalt antal inrymda personer"; break;
case "a":  					$messaggio = "till"; break;
case "Il numero delle persone verrà cambiato da":	$messaggio = "Antalet personer kommer &auml;ndras fr&aring;n"; break;
case "persone":  				$messaggio = "personer"; break;
case "è stata <b>cancellata</b>":  		$messaggio = "har <b>tagits bort</b>"; break;
case "Si devono fare i seguenti spostamenti nei periodi della <div style=\"display: inline; color: blue;\">regola di assegnazione 1</div>":	$messaggio = "Flyttningars som m&aring;ste g&ouml;ras under perioder h&ouml;rande till <div style=\"display: inline; color: blue;\">&ouml;verl&aring;telseregel 1</div>"; break;
case "La prenotazione dal":  			$messaggio = "Bokningen fr&aring;n"; break;
case "a nome di":  				$messaggio = "f&ouml;r herr/fru"; break;
case "La prenotazione verrà":  			$messaggio = "Bokningen kommer"; break;
case "mantenuta":  				$messaggio = "vara kvar"; break;
case "spostata":  				$messaggio = "flyttas"; break;
case "La tariffa":  				$messaggio = "Priset"; break;
case "non esiste più, cambiala prima di aggiornare":	$messaggio = "finns inte l&auml;ngre, &auml;ndra det f&ouml;re du uppdaterar"; break;
case "<b>Non</b> è stato ancora inserito il prezzo della":	$messaggio = "Du m&aring;ste <b>fortfarande</b> ange priset f&ouml;r"; break;
case "per la settimana dal":  			$messaggio = "f&ouml;r veckan fr&aring;n"; break;
case "per il giorno dal":  			$messaggio = "f&ouml;r dagen fr&aring;n"; break;
case "La tariffa verrà cambiata da":  		$messaggio = "Priset kommer &auml;ndras fr&aring;n"; break;
case "Il costo aggiuntivo":  			$messaggio = "Extrakostnaden"; break;
case "Il costo aggiuntivo unico":  		$messaggio = "Den enkla extrakostnaden"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "Den veckoliga extrakostnaden"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "Den dagliga extrakostnaden"; break;
case "non può essere moltiplicato per":  	$messaggio = "kan inte multipliceras med"; break;
case "verrà moltiplicato per":  		$messaggio = "kommer multipliceras med"; break;
case "prima era":  				$messaggio = "det var"; break;
case "Le settimane del costo aggiuntivo":  	$messaggio = "Veckorna med extrakostnaden"; break;
case "I giorni del costo aggiuntivo":  		$messaggio = "Dagarna med extrakostnaden"; break;
case "<b>superano</b> la durata della prenotazione":	$messaggio = "<b>&ouml;verstiger</b> bokningens varaktighet"; break;
case "verranno cabiate da":  			$messaggio = "kommer &auml;ndras fr&aring;n"; break;
case "verranno cabiati da":  			$messaggio = "kommer &auml;ndras fr&aring;n"; break;
case "verranno cabiate":  			$messaggio = "kommer &auml;ndras"; break;
case "verranno cabiati":  			$messaggio = "kommer &auml;ndras"; break;
case "<b>non</b> verranno cambiate":  		$messaggio = "kommer <b>inte</b> &auml;ndras"; break;
case "<b>non</b> verranno cambiati":  		$messaggio = "kommer <b>inte</b> &auml;ndras"; break;
case "su":  					$messaggio = "p&aring;"; break;
case "Il prezzo del costo aggiuntivo":  	$messaggio = "Priset f&ouml;r extrakostnaden"; break;
case "verrà tolto":  				$messaggio = "kommer tas bort"; break;
case "I dati del costo aggiuntivo <b>straordinario</b> sono <div style=\"display: inline; color: red;\">errati o mancanti</div>":	$messaggio = "Data f&ouml;r de <b>extraordin&auml;ra</b> extrakostnaderna &auml;r <div style=\"display: inline; color: red;\">felaktiga eller saknas</div>"; break;
case "verrà aggiunto":  			$messaggio = "kommer l&auml;ggas till"; break;
case "come letto aggiuntivo":  			$messaggio = "som en extras&auml;ng"; break;
case "Le settimane del nuovo costo aggiuntivo":	$messaggio = "Veckorna med den nya extrakostnaden"; break;
case "I giorni del nuovo costo aggiuntivo":  	$messaggio = "Dagarna med den nya extrakostnaden"; break;
case "Lo <div style=\"display: inline; color: red;\">sconto</div> inserito":	$messaggio = "Den infogade <div style=\"display: inline; color: red;\">rabatten</div>"; break;
case "supera il costo totale senza sconto":  	$messaggio = "&auml;r st&ouml;rre &auml;n den totala kostnaden med rabatt"; break;
case "Lo sconto verrà cambiato da":  		$messaggio = "Rabatten kommer &auml;ndras fr&aring;n"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div> inserita":	$messaggio = "Den infogade <div style=\"display: inline; color: red;\">depositionen</div>"; break;
case "supera il costo totale":  		$messaggio = "&auml;r st&ouml;rre &auml;n den totala kostnaden"; break;
case "La caparra verrà cambiata da":  		$messaggio = "Depositionen kommer &auml;ndras fr&aring;n"; break;
case "La <div style=\"display: inline; color: red;\">caparra</div>":  	$messaggio = "<div style=\"display: inline; color: red;\">Depositionen</div>"; break;
case "supera il nuovo costo totale":  		$messaggio = "&auml;r st&ouml;rre &auml;n den nya totala kostnaden"; break;
case "La cifra <div style=\"display: inline; color: red;\">pagata</div> inserita":	$messaggio ="Det infogade <div style=\"display: inline; color: red;\">betalda</div> beloppet"; break;
case "I soldi pagati verranno cambiati da":  		$messaggio = "Betalad summa kommer &auml;ndras fr&aring;n"; break;
case "verrà <b>confermata</b>":  			$messaggio = "kommer <b>bekr&auml;ftas</b>"; break;
case "Verrà tolta la <b>conferma</b> alla prenotazione":	$messaggio = "<b>Bekr&auml;ftelsen</b> kommer tas bort fr&aring;n bokning"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "<b>Kommentaren</b> kommer &auml;ndras"; break;
case "Il <b>commento</b> verrà cancellato":  	$messaggio = "<b>Kommentaren</b> kommer tas bort"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "modificata":  				$messaggio = "&auml;ndrad"; break;
case "<b>non è stata modificata</b> perchè la tabella prenotazioni è cambiata nel frattempo":	$messaggio = "<b>har inte &auml;ndrats</b> eftersom bokningstabellen har &auml;ndrats under tiden"; break;
case "verrà cambiato da":  			$messaggio = "kommer &auml;ndras fr&aring;n"; break;
case "con costo agg.":  			$messaggio = "med extrakostnad"; break;
case "Cliente":  				$messaggio = "Kund"; break;
case "Non c'è nussun periodo delle regole 1 in cui sia consentito inserire prenotazioni per l'utente":	$messaggio = "Det finns inga perioder med &ouml;verl&aring;telseregel 1 i vilka det &auml;r till&aring;tet att infoga bokningar f&ouml;r anv&auml;ndare"; break;
case "Prenotazione non confermata":  		$messaggio = "Bokning inte bekr&auml;ftad"; break;
case "Inserita dall'utente":  			$messaggio = "Infogad av anv&auml;ndare"; break;
case "Si considererà l'utente":  		$messaggio = "Anv&auml;ndare"; break;
case "come colui che ha inserito la prenotazione":	$messaggio = "kommer anses vara den som infogade bokningen"; break;
case "Non si possono inserire altri costi":  	$messaggio = "Du kan inte l&auml;gga till fler kostnader"; break;
case "in questo periodo, già":  		$messaggio = "under denna perioden, redan"; break;
case "presenti":  				$messaggio = "n&auml;rvarande"; break;
case "Non si puo inserire il costo aggiuntivo":	$messaggio = "Extrakostnaden"; break;
case "in questo periodo":  			$messaggio = "kan inte l&auml;ggas till under den h&auml;r perioden"; break;
case "Settimane":  				$messaggio = "Veckor"; break;
case "Giorni":  				$messaggio = "Dagara"; break;
case "mostra":  				$messaggio = "visa"; break;
case "nascondi":  				$messaggio = "g&ouml;m"; break;
case "numeri diversi":  			$messaggio = "olika antal"; break;
case "Non si può inserire più di un costo aggiuntivo con percentuale sul prezzo totale per prenotazione":	$messaggio = "Du kan inte l&auml;gga till mer &auml;n en extrakostnad med procentandel p&aring; det totala bokningspriset"; break;
case "Scegliere le settimane in cui applicare il costo aggiuntivo":	$messaggio = "V&auml;lj veckorna som extrakostnaden ska till&auml;mpas f&ouml;r"; break;
case "Scegliere i giorni in cui applicare il costo aggiuntivo":	$messaggio = "V&auml;lj dagarna som extrakostnaden ska till&auml;mpas f&ouml;r"; break;
case "Si deve inserire il numero delle persone per il costo aggiuntivo":	$messaggio = "Antalet personer m&aring;ste infogas f&ouml;r extrakostnaden"; break;
case "Non si possono inserire altri costi":  	$messaggio = "Du kan inte l&auml;gga till fler kostnader"; break;
case "in questo periodo, già":  		$messaggio = "under denna perioden, redan"; break;
case "presenti":  				$messaggio = "n&auml;rvarande"; break;
case "della tariffa":  				$messaggio = "av priset"; break;
case "del totale":  				$messaggio = "av totalen"; break;
case "della caparra":  				$messaggio = "av depositionen"; break;
case "del resto caparra":  			$messaggio = "av &aring;terstoden av depositionen"; break;
case "di base":  				$messaggio = "av basen"; break;
case "totale":  				$messaggio = "totalt"; break;
case "registra entrata":  			$messaggio = "incheckning"; break;
case "cancella entrata":  			$messaggio = "avbryt incheckning"; break;
case "registra uscita":  			$messaggio = "utcheckning"; break;
case "cancella uscita":  			$messaggio = "avbryt utcheckning"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Varning</div>: incheckning redan registrerad"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di entrata non registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Varning</div>: incheckning inte registrerad"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita già registrato":	$messaggio = "<div style=\"display: inline; color: red;\">Varning</div>: utcheckning redan registrerad"; break;
case "<div style=\"display: inline; color: red;\">Attentione</div>: orario di uscita non registrato, registrare prima l'entrata":	$messaggio = "<div style=\"display: inline; color: red;\">Varning</div>: utckecning inte registrerad, registrera incheckning f&ouml;rst"; break;
case "Metodo pagamento caparra":  		$messaggio = "Depositionsbetalningsmetod"; break;
case "Il metodo di pagamento della caparra verrà cambiato a":	$messaggio = "Depositionsbetalningsmetoden kommer &auml;ndras till"; break;
case "Metodo di pagamento":  			$messaggio = "Betalningsmetod"; break;
case "metodo di pagamento":  			$messaggio = "betalningsmetod"; break;
case "Normalmente le prenotazioni già iniziate e quelle che hanno registrato l'orario di entrata non vengono spostate":	$messaggio = "Normalt flyttas inte redan p&aring;b&ouml;rjade bokningar och dom som har checkat in"; break;
case "Prova di nuovo":  			$messaggio = "F&ouml;rs&ouml;k igen"; break;
case "muovendo anche le prenotazioni iniziate dopo il":	$messaggio = "flytta &auml;ven bokningar p&aring;b&ouml;rjade efter"; break;
case "considerate fisse perchè <div style=\"display: inline; color: red;\">ad oggi già iniziate</div>":	$messaggio = "anses fixerad eftersom <div style=\"display: inline; color: red;\">idag redan p&aring;b&ouml;rjade</div>"; break;
case "è incompatibile con la tariffa selezionata":	$messaggio = "&auml;r inkompatibla med valt pris"; break;
case "non può essere applicato":  		$messaggio = "kan inte till&auml;mpas"; break;
case "Non si può cambiare l'assegnazione di una prenotazione che si trova <div style=\"display: inline; color: red;\">tra due anni</div>":	$messaggio = "Du kan inte &auml;ndra tilldelningen f&ouml;r en bokning som &auml;r <div style=\"display: inline; color: red;\">mellan tv&aring; &aring;r</div>"; break;
case "Modifica nell'anno precedente":  		$messaggio = "&Auml;ndra under tidigare &aring;r"; break;
case "Orario entrata stimato":  		$messaggio = "Uppskattad incheckningstid"; break;
case "L'orario stimato di entrata verrà cambiato a":	$messaggio = "Den uppskattade incheckningstiden kommer &auml;ndras till"; break;
case "Codice prenotazione":  			$messaggio = "Bokningskod"; break;
case "rigenera":  				$messaggio = "generera ny"; break;
case "Non si è potuto spostare la prenotazione per la registrazione dell'entrata":	$messaggio = "Det var inte m&ouml;jligt att flytta bokningen p&aring; grund av incheckningen"; break;
case "Cambia cliente":  			$messaggio = "&Auml;ndra kund"; break;
case "Nuovo titolare della prenotazione":	$messaggio = "Ny huvudbokare"; break;
case "cliente numero":  			$messaggio = "kundnummer"; break;
case "Il titolare della prenotazione":  	$messaggio = "Huvudbokaren f&ouml;r bokningen"; break;
case "Il titolare delle prenotazioni":  	$messaggio = "Huvudbokaren f&ouml;r bokningarna"; break;
case "Cliente non trovato":  			$messaggio = "Kund inte hittad"; break;
case "Annulla":  				$messaggio = "Avbryt"; break;
case "Prenotazioni vicine":  			$messaggio = "N&auml;rliggande bokningar"; break;
case "numero":  				$messaggio = "antal"; break;
case "La prenotazione numero":  		$messaggio = "Bokningsnumret"; break;
case "non esiste":  				$messaggio = "finns inte"; break;
case "Ospiti della prenotazione":  		$messaggio = "Bokningsg&auml;ster"; break;
case "Modifica gli ospiti":  			$messaggio = "&Auml;ndra g&auml;ster"; break;
case "nato":  					$messaggio = "f&ouml;dd"; break;
case "nata":  					$messaggio = "f&ouml;dd"; break;
case "il":  					$messaggio = ""; break;
case " a":  					$messaggio = " i"; break;
case "scade":  					$messaggio = "upph&ouml;r att g&auml;lla"; break;
case "Codice fiscale":  			$messaggio = "Skattekod"; break;
case "Origine":  				$messaggio = "Ursprung"; break;
case "L'origine della prenotazione verrà cambiata a":	$messaggio = "Bokningsursprunget kommer &auml;ndras till"; break;
case "Modifica o cancella le prenotazioni":  	$messaggio = "&Auml;ndra eller ta bort bokningar"; break;
case "Modifica le prenotazioni":  		$messaggio = "&Auml;ndra bokningar"; break;
case "Cancella le prenotazioni":  		$messaggio = "Ta bort bokningar"; break;
case "della prenotazione":  			$messaggio = "fr&aring;n bokningen"; break;
case "per la prenotazione":  			$messaggio = "f&ouml;r bokningen"; break;
case "Data inserimento":  			$messaggio = "Infogningsdatum"; break;
case "con i costi aggiuntivi selezionati":  	$messaggio = "med valda extrakostnader"; break;
case "I beni richiesti dal costo":  		$messaggio = "De tillg&aring;ngar som beh&ouml;vs f&ouml;r kostnaden"; break;
case "non sono disponibili nell'inventario":  	$messaggio = "&auml;r inte tillg&auml;ngliga i inventoriet"; break;
case "pren.":  					$messaggio = "bokn."; break;
case "tutte":  					$messaggio = "all"; break;
case "ln.":  					$messaggio = "ln."; break;
case "Modifica Prenotazioni":  			$messaggio = "Modify reservations"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "°</b> piano":  				$messaggio = "</b>"; break;
case "<b><big>i</big></b>":  			$messaggio = "<b><big>i</big></b>"; break;
case "Si deve inserire il <span class=\"colred\">numero delle persone</span> per la tariffa selezionata":	$messaggio = "The <span class=\"colred\">number of people</span> must be inserted for the selected rate"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "i beni richiesti alla registrazione dell'entrata":	$messaggio = "items needed by check-in"; break;
case "Commissioni":  				$messaggio = "Commissions"; break;
case "Ricalcola le commissioni in base alla nuova tariffa":	$messaggio = "Calculate again the commissions from the new rate"; break;
case "Le commissioni verranno cambiate da":	$messaggio = "Commissions will be changed from"; break;
case "tasse":  					$messaggio = "taxes"; break;
case "Il prezzo totale cambierà da":  		$messaggio = "The total price will change from"; break;
case "saldo di":  				$messaggio = "balance"; break;
case "Altre prenotazioni dello stesso cliente nello stesso periodo":	$messaggio = "Other reservations from the same client in the same period"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "vi sono altre prenotazioni dello stesso cliente nello stesso periodo che ancora non sono state pagate":	$messaggio = "there are other reservations from the same client in the same period that have not been paid yet"; break;
case "Il saldo totale pagato sarà di":  	$messaggio = "The total balance of money paid will be"; break;
case "della tariffa fissa":  			$messaggio = "of fixed rate"; break;
case "di una persona":  			$messaggio = "of one person"; break;
case "non può essere moltiplicato per più di":	$messaggio = "can not be multiplied by more than"; break;
case "Nuovo costo aggiuntivo":  		$messaggio = "New extra cost"; break;
case "aggiungi promemoria per l'entrata":  	$messaggio = "add a reminder for checkin"; break;
case "aggiungi promemoria per l'uscita":  	$messaggio = "add a reminder for checkout"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>entrata</em>":	$messaggio = "A <b>reminder</b> for <em>checkin</em> will be added"; break;
case "Verrà aggiunto un <b>promemoria</b> per l'<em>uscita</em>":	$messaggio = "A <b>reminder</b> for <em>checkout</em> will be added"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "La <b>tariffa</b> richiesta è <span class=\"colred\">chiusa</span> in questo periodo":	$messaggio = "The requested <b>rate</b> is <span class=\"colred\">closed</span> in this period"; break;
case "cambia il commento":  			$messaggio = "change comment"; break;
case "Il commento":  				$messaggio = "Comment"; break;
case "verrà cambiato":  			$messaggio = "will be changed"; break;
case "per ":  					$messaggio = "for "; break;
case "Il numero di":  				$messaggio = "The number of"; break;
case "Valuta":  				$messaggio = "Currency"; break;
case "Valuta caparra":  			$messaggio = "Deposit currency"; break;
case "Al cambio attuale":  			$messaggio = "At current exchange rate"; break;
case "email":  					$messaggio = "email"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC/codice":  				$messaggio = "certified email"; break;
case "cancella in modo permanente":  		$messaggio = "delete permanently"; break;
case "in modo permanente":  			$messaggio = "permanently"; break;
case "Prenotazione cancellata":  		$messaggio = "Deleted reservation"; break;
case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
case "Data o orario stimato di entrata <span class=\"colred\">errato</span>":	$messaggio = "<span class=\"colred\">Wrong</span> estimated check-in time or date"; break;
case "Data cancellazione":  			$messaggio = "Deletion date"; break;
case "Cancellata dall'utente":  		$messaggio = "Deleted by user"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>